Module: EventMachine
- Defined in:
- lib/pubsubhubbub/client.rb,
lib/pubsubhubbub/version.rb
Overview
#-- Copyright (C)2009 Ilya Grigorik
You can redistribute this under the terms of the Ruby #--
Defined Under Namespace
Classes: PubSubHubbub
#-- Copyright (C)2009 Ilya Grigorik
You can redistribute this under the terms of the Ruby #--
Classes: PubSubHubbub